![Baseten](https://cdn.baseten.co/docs/production/PyPiHeaderBaseten.jpeg)

This package contains the Python client and CLI for Baseten.

Baseten is an ML Application Builder for data science and machine learning teams. We simplify the set-up of back-ends, front-ends, and MLOps—so your models get used faster. Baseten makes it simple to serve your machine learning models, integrate with custom business logic, and design powerful web apps for business users, all without configuring any infrastructure or writing React or JS. API endpoints, release management, and scalability all come out of the box.

Visit our official documentation at [docs.baseten.co](https://docs.baseten.co).